@@ -3,6 +3,8 @@
 import sys
 import json
 import shutil
+import time
+import uuid
 from pathlib import Path
 import click
 from typing import Optional
@@ -12,6 +14,10 @@ from .client import RelayClient
 from .hooks import HooksInstaller
 
 
+# Relay server configuration for response polling
+RELAY_URL = "https://relay.vgbndg.net"
+
+
 def install_scripts() -> dict:
     """Install hook scripts to ~/.watchcode/ directory.
 
@@ -91,6 +97,47 @@ def install_scripts() -> dict:
     return result
 
 
+def poll_for_response(auth_token: str, notification_id: str, timeout: int = 55) -> Optional[dict]:
+    """Poll relay server for Watch response.
+
+    Args:
+        auth_token: The WatchCode auth token
+        notification_id: The notification ID to poll for
+        timeout: Maximum time to wait in seconds
+
+    Returns:
+        Response dict with 'action' key if found, None on timeout
+    """
+    import httpx
+
+    url = f"{RELAY_URL}/response/{auth_token}/{notification_id}"
+    start_time = time.time()
+    poll_count = 0
+
+    while time.time() - start_time < timeout:
+        poll_count += 1
+        elapsed = time.time() - start_time
+
+        try:
+            with httpx.Client(timeout=5.0) as client:
+                response = client.get(url)
+                if response.status_code == 200:
+                    data = response.json()
+                    if data.get('found'):
+                        return data.get('response', {})
+        except Exception:
+            pass  # Network errors, just retry
+
+        # Show progress every 10 seconds
+        if poll_count % 5 == 0:
+            remaining = int(timeout - elapsed)
+            click.echo(f"  Still waiting... ({remaining}s remaining)")
+
+        time.sleep(2)  # Poll every 2 seconds
+
+    return None
+
+
 @click.group()
 @click.version_option(package_name="watchcode-cli")
 def main():
@@ -124,7 +171,8 @@ def _setup_manual(config: Config) -> str:
 
 
 @main.command()
-def setup():
+@click.option('--no-hooks', is_flag=True, help='Skip Claude Code hook installation')
+def setup(no_hooks: bool):
     """Interactive setup - configure WatchCode with your setup code."""
     config = Config()
     installer = HooksInstaller()
@@ -167,19 +215,19 @@ def setup():
     click.echo(f"Setup code saved: {config.format_token_display(clean_token)}")
     click.echo()
 
-    # Ask to install hooks
-    if click.confirm("Install Claude Code hooks?", default=True):
+    # Auto-install hooks (unless --no-hooks flag is used)
+    if no_hooks:
+        click.echo("Skipped hook installation (--no-hooks flag).")
+        click.echo("Run 'watchcode install-hooks' later to enable Claude Code integration.")
+    else:
+        click.echo("Installing Claude Code hooks... ", nl=False)
         result = installer.install_hooks()
+        click.echo("done")
 
         if result["installed"]:
-            click.echo(f"Installed hooks: {', '.join(result['installed'])}")
+            click.echo(f"  Installed: {', '.join(result['installed'])}")
         if result["skipped"]:
-            click.echo(f"Already installed: {', '.join(result['skipped'])}")
-
-        click.echo()
-        click.echo("Hooks installed successfully!")
-    else:
-        click.echo("Skipped hook installation. Run 'watchcode install-hooks' later.")
+            click.echo(f"  Already installed: {', '.join(result['skipped'])}")
 
     click.echo()
 
@@ -278,8 +326,13 @@ def fix_hooks():
 
 
 @main.command()
-def test():
-    """Send a test notification to your Apple Watch."""
+@click.option('--no-wait', is_flag=True, help='Send notification and exit without waiting for response')
+def test(no_wait: bool):
+    """Send interactive test notification to your Apple Watch.
+
+    By default, sends a test notification with Allow/Deny buttons and waits
+    for your response. Use --no-wait to send a simple notification and exit.
+    """
     config = Config()
 
     if not config.is_configured():
@@ -288,16 +341,57 @@ def test():
 
     try:
         client = RelayClient(config)
-        click.echo("Sending test notification...")
+        auth_token = config.get_auth_token()
 
-        response = client.send_test_notification()
+        if no_wait:
+            # Simple one-way notification (legacy behavior)
+            click.echo("Sending test notification...")
+            response = client.send_test_notification()
 
-        if response.get("success"):
-            click.echo("Test notification sent successfully!")
-            click.echo("Check your Apple Watch for the notification.")
+            if response.get("success"):
+                click.echo("Test notification sent successfully!")
+                click.echo("Check your Apple Watch for the notification.")
+            else:
+                click.echo(f"Error: {response.get('error', 'Unknown error')}", err=True)
+                sys.exit(1)
         else:
-            click.echo(f"Error: {response.get('error', 'Unknown error')}", err=True)
-            sys.exit(1)
+            # Interactive test with approval buttons
+            notification_id = str(uuid.uuid4())
+            click.echo("Sending test notification with approval buttons...")
+
+            # Send as permission_request type (has Allow/Deny buttons)
+            response = client.send_notification(
+                event="permission_request",
+                message="Test notification - tap Allow or Deny",
+                session_id=f"test-{int(time.time())}",
+                requires_action=True,
+                notification_id=notification_id,
+                metadata={"source": "watchcode-cli-test"}
+            )
+
+            if not response.get("success"):
+                click.echo(f"Error: {response.get('error', 'Unknown error')}", err=True)
+                sys.exit(1)
+
+            click.echo("Test notification sent!")
+            click.echo("Waiting for response (55s timeout)...")
+
+            # Poll for response
+            watch_response = poll_for_response(auth_token, notification_id, timeout=55)
+
+            if watch_response:
+                action = watch_response.get('action', 'unknown')
+                click.echo(f"Received: {action.upper()}")
+                click.echo()
+                click.echo("Test successful! The full approval flow is working.")
+            else:
+                click.echo("Timeout - no response received.")
+                click.echo()
+                click.echo("This could mean:")
+                click.echo("  - Notification didn't arrive on Watch")
+                click.echo("  - User didn't respond in time")
+                click.echo("  - Response didn't make it back")
+                sys.exit(1)
 
     except Exception as e:
         click.echo(f"Error: {str(e)}", err=True)
